@@ -7,17 +7,17 @@ require_once 'Horde/String.php';
  * web client. Browser identification is performed by examining the
  * HTTP_USER_AGENT environmental variable provide by the web server.
  *
- * $Horde: framework/Browser/Browser.php,v 1.153 2004/12/22 15:07:18 chuck Exp $
+ * $Horde: framework/Browser/Browser.php,v 1.153.2.2 2005/01/04 11:53:11 jan Exp $
  *
- * Copyright 1999-2004 Chuck Hagenbuch <chuck@horde.org>
- * Copyright 1999-2004 Jon Parise <jon@horde.org>
+ * Copyright 1999-2005 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 1999-2005 Jon Parise <jon@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
  * @author  Jon Parise <jon@horde.org>
- * @version $Revision: 1.153 $
+ * @version $Revision: 1.153.2.2 $
  * @since   Horde 1.3
  * @package Horde_Browser
  */
@@ -162,6 +162,7 @@ class Browser {
         'empty_file_input_value'     => false,
         'must_cache_forms'           => false,
         'no_filename_spaces'         => false,
+        'no_hidden_overflow_tables'  => false,
         'ow_gui_1.3'                 => false,
         'png_transparency'           => false,
         'scrollbar_in_way'           => false,
@@ -402,6 +403,7 @@ class Browser {
                 // rendering engine.
                 $this->setBrowser('konqueror');
                 $this->setQuirk('empty_file_input_value');
+                $this->setQuirk('no_hidden_overflow_tables');
                 $this->_majorVersion = $version[1];
                 if (isset($version[2])) {
                     $this->_minorVersion = $version[2];
