@@ -13,15 +13,14 @@
  *
  *   http://alexandre.alapetite.net/doc-alex/domxml-php4-php5/
  *
- * $Horde: framework/Horde/Horde/Config.php,v 1.80 2004/12/19 15:59:54 jan Exp $
+ * $Horde: framework/Horde/Horde/Config.php,v 1.80.2.2 2005/01/03 12:19:02 jan Exp $
  *
- * Copyright 2002-2004 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 2002-2005 Chuck Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
- * @version $Revision: 1.80 $
  * @since   Horde 3.0
  * @package Horde_Framework
  */
@@ -907,7 +906,7 @@ class Horde_Config {
  * system.
  *
  * @author  Chuck Hagenbuch <chuck@horde.org>
- * @version $Revision: 1.80 $
+ * @version $Revision: 1.80.2.2 $
  * @since   Horde 3.0
  * @package Horde_Framework
  */
@@ -972,6 +971,9 @@ class ConfigForm extends Horde_Form {
                 $selected = $this->_vars->getExists($varname, $wasset);
                 $var_params = array();
                 $select_option = true;
+                if (is_bool($configitem['default'])) {
+                    $configitem['default'] = $configitem['default'] ? 'true' : 'false';
+                }
                 foreach ($configitem['switch'] as $option => $case) {
                     $var_params[$option] = $case['desc'];
                     if ($option == $configitem['default']) {
