@@ -5,16 +5,15 @@
  * The Horde_Form:: package provides form rendering, validation, and
  * other functionality for the Horde Application Framework.
  *
- * $Horde: framework/Form/Form.php,v 1.306.2.1 2004/12/22 22:07:53 jan Exp $
+ * $Horde: framework/Form/Form.php,v 1.306.2.3 2005/01/04 17:04:49 chuck Exp $
  *
- * Copyright 2001-2004 Robert E. Coyle <robertecoyle@hotmail.com>
- * Copyright 2001-2004 Chuck Hagenbuch <chuck@horde.org>
+ * Copyright 2001-2005 Robert E. Coyle <robertecoyle@hotmail.com>
+ * Copyright 2001-2005 Chuck Hagenbuch <chuck@horde.org>
  *
  * See the enclosed file COPYING for license information (LGPL). If you
  * did not receive this file, see http://www.fsf.org/copyleft/lgpl.html.
  *
  * @author  Robert E. Coyle <robertecoyle@hotmail.com>
- * @version $Revision: 1.306.2.1 $
  * @since   Horde 3.0
  * @package Horde_Form
  */
@@ -2313,15 +2312,31 @@ class Horde_Form_Type_date extends Horde_Form_Type {
     function getAgo($timestamp)
     {
         require_once 'Date/Calc.php';
-        $ago = Date_Calc::dateDiff(date('j', $timestamp), date('n', $timestamp), date('Y', $timestamp),
-                                   date('j'), date('n'), date('Y'));
+        $diffdays = Date_Calc::dateDiff(date('j', $timestamp),
+                                        date('n', $timestamp),
+                                        date('Y', $timestamp),
+                                        date('j'), date('n'), date('Y'));
 
-        if ($ago == 0) {
+        /* An error occured. */
+        if ($diffdays == -1) {
+            return;
+        }
+
+        $ago = $diffdays * Date_Calc::compareDates(date('j', $timestamp),
+                                                   date('n', $timestamp),
+                                                   date('Y', $timestamp),
+                                                   date('j'), date('n'),
+                                                   date('Y'));
+        if ($ago < -1) {
+            return sprintf(_(" (%s days ago)"), $diffdays);
+        } elseif ($ago == -1) {
+            return _(" (yesterday)");
+        } elseif ($ago == 0) {
             return _(" (today)");
         } elseif ($ago == 1) {
-            return _(" (yesterday)");
+            return _(" (tomorrow)");
         } else {
-            return sprintf(_(" (%s days ago)"), $ago);
+            return sprintf(_(" (in %s days)"), $diffdays);
         }
     }
 
