@@ -3,12 +3,12 @@
  *
  * Provides the javascript class to create dynamic trees.
  *
- * Copyright 2003-2004 Marko Djukic <marko@oblo.com>
+ * Copyright 2003-2005 Marko Djukic <marko@oblo.com>
  *
  * See the enclosed file COPYING for license information (GPL). If you did not
  * receive this file, see http://www.fsf.org/copyleft/gpl.html.
  *
- * $Horde: horde/templates/javascript/tree.js,v 1.62 2004/12/18 23:50:09 jan Exp $
+ * $Horde: horde/templates/javascript/tree.js,v 1.62.2.2 2005/01/03 12:25:46 jan Exp $
  *
  * @author  Marko Djukic <marko@oblo.com>
  * @package Horde_Tree
@@ -540,7 +540,7 @@ Horde_Tree.prototype.saveState = function(nodeId, expanded)
 Horde_Tree.prototype._getCookie = function(name)
 {
     var dc = document.cookie;
-    var prefix = name + '=';
+    var prefix = name + '=exp';
     var begin = dc.indexOf('; ' + prefix);
     if (begin == -1) {
         begin = dc.indexOf(prefix);
@@ -559,8 +559,8 @@ Horde_Tree.prototype._getCookie = function(name)
 
 Horde_Tree.prototype._setCookie = function(name, value)
 {
-    var curCookie = name + '=' + escape(value);
-    curCookie = curCookie + ';DOMAIN=<?php echo $GLOBALS['conf']['cookie']['domain']; ?>;PATH=<?php echo $GLOBALS['conf']['cookie']['path']; ?>;';
+    var curCookie = name + '=exp' + escape(value);
+    curCookie += ';DOMAIN=<?php echo $GLOBALS['conf']['cookie']['domain']; ?>;PATH=<?php echo $GLOBALS['conf']['cookie']['path']; ?>;';
     document.cookie = curCookie;
 }
 
